diff --git a/web/pgadmin/browser/collection.py b/web/pgadmin/browser/collection.py
index 6c1633451..839aa52a2 100644
--- a/web/pgadmin/browser/collection.py
+++ b/web/pgadmin/browser/collection.py
@@ -26,6 +26,11 @@ class CollectionNodeModule(PgAdminModule, PGChildModule):
     browser_url_prefix = BrowserPluginModule.browser_url_prefix
     SHOW_ON_BROWSER = True
 
+    _BROWSER_CSS_PATH = 'browser/css'
+
+    _NODE_CSS = 'node.css'
+    _COLLECTION_CSS = 'collection.css'
+
     def __init__(self, import_name, **kwargs):
         kwargs.setdefault("url_prefix", self.node_path)
         kwargs.setdefault("static_url_path", '/static')
@@ -128,11 +133,11 @@ class CollectionNodeModule(PgAdminModule, PGChildModule):
         """
         snippets = [
             render_template(
-                "browser/css/collection.css",
+                "/".join([self._BROWSER_CSS_PATH, self._COLLECTION_CSS]),
                 node_type=self.node_type
             ),
             render_template(
-                "browser/css/node.css",
+                "/".join([self._BROWSER_CSS_PATH, self._NODE_CSS]),
                 node_type=self.node_type,
                 _=gettext
             )
diff --git a/web/pgadmin/browser/server_groups/servers/databases/__init__.py b/web/pgadmin/browser/server_groups/servers/databases/__init__.py
index 5e2ed1c8a..78a1ec69f 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/__init__.py
+++ b/web/pgadmin/browser/server_groups/servers/databases/__init__.py
@@ -39,6 +39,9 @@ class DatabaseModule(CollectionNodeModule):
     _NODE_TYPE = 'database'
     _COLLECTION_LABEL = _("Databases")
 
+    _DATABASE_CSS_PATH = 'databases/css'
+    _DATABASE_CSS = 'database.css'
+
     def __init__(self, *args, **kwargs):
         self.min_ver = None
         self.max_ver = None
@@ -67,12 +70,12 @@ class DatabaseModule(CollectionNodeModule):
         """
         snippets = [
             render_template(
-                "browser/css/collection.css",
+                "/".join([self._BROWSER_CSS_PATH, self._COLLECTION_CSS]),
                 node_type=self.node_type,
                 _=_
             ),
             render_template(
-                "databases/css/database.css",
+                "/".join([self._DATABASE_CSS_PATH, self._DATABASE_CSS]),
                 node_type=self.node_type,
                 _=_
             )
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/tables/__init__.py b/web/pgadmin/browser/server_groups/servers/databases/schemas/tables/__init__.py
index 76b71cb31..bf20b7f4b 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/tables/__init__.py
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/tables/__init__.py
@@ -89,25 +89,25 @@ class TableModule(SchemaChildModule):
         """
         snippets = [
             render_template(
-                "browser/css/collection.css",
+                "/".join([self._BROWSER_CSS_PATH, self._COLLECTION_CSS]),
                 node_type=self.node_type,
             ),
             render_template(
-                "browser/css/node.css",
+                "/".join([self._BROWSER_CSS_PATH, self._NODE_CSS]),
                 node_type=self.node_type,
             ),
             render_template(
-                "browser/css/node.css",
+                "/".join([self._BROWSER_CSS_PATH, self._NODE_CSS]),
                 node_type='table',
                 file_name='table-inherited',
             ),
             render_template(
-                "browser/css/node.css",
+                "/".join([self._BROWSER_CSS_PATH, self._NODE_CSS]),
                 node_type='table',
                 file_name='table-inherits',
             ),
             render_template(
-                "browser/css/node.css",
+                "/".join([self._BROWSER_CSS_PATH, self._NODE_CSS]),
                 node_type='table',
                 file_name='table-multi-inherit',
             ),
@@ -594,7 +594,7 @@ class TableView(BaseTableView, DataTypeReader, VacuumSettings,
         if not status:
             return res
         if not res['rows']:
-            return gone(gettext("The specified table could not be found."))
+            return gone(gettext(self.TABLE_NOT_FOUND_MSG))
 
         return super(TableView, self).properties(
             gid, sid, did, scid, tid, res=res
@@ -636,7 +636,7 @@ class TableView(BaseTableView, DataTypeReader, VacuumSettings,
 
         elif len(res['rows']) == 0:
             return False, gone(
-                gettext("The specified table could not be found."))
+                gettext(self.TABLE_NOT_FOUND_MSG))
 
         # Update autovacuum properties
         self.update_autovacuum_properties(res['rows'][0])
@@ -729,14 +729,16 @@ class TableView(BaseTableView, DataTypeReader, VacuumSettings,
             if data and 'tid' in data:
                 SQL = render_template(
                     "/".join([
-                        self.table_template_path, 'get_columns_for_table.sql'
+                        self.table_template_path,
+                        self._GET_COLUMNS_FOR_TABLE_SQL
                     ]),
                     tid=data['tid']
                 )
             elif data and 'tname' in data:
                 SQL = render_template(
                     "/".join([
-                        self.table_template_path, 'get_columns_for_table.sql'
+                        self.table_template_path,
+                        self._GET_COLUMNS_FOR_TABLE_SQL
                     ]),
                     tname=data['tname']
                 )
@@ -778,7 +780,7 @@ class TableView(BaseTableView, DataTypeReader, VacuumSettings,
                 SQL = render_template(
                     "/".join(
                         [self.table_template_path,
-                         'get_columns_for_table.sql']
+                         self._GET_COLUMNS_FOR_TABLE_SQL]
                     ), tid=row['oid']
                 )
 
@@ -1118,7 +1120,7 @@ class TableView(BaseTableView, DataTypeReader, VacuumSettings,
                             'Error: Object not found.'
                         ),
                         info=gettext(
-                            'The specified table could not be found.\n'
+                            self.TABLE_NOT_FOUND_MSG + '\n'
                         )
                     )
 
@@ -1160,7 +1162,7 @@ class TableView(BaseTableView, DataTypeReader, VacuumSettings,
                 return internal_server_error(errormsg=res)
 
             if len(res['rows']) == 0:
-                return gone(gettext("The specified table could not be found."))
+                return gone(gettext(self.TABLE_NOT_FOUND_MSG))
 
             return super(TableView, self).truncate(
                 gid, sid, did, scid, tid, res
@@ -1265,8 +1267,7 @@ class TableView(BaseTableView, DataTypeReader, VacuumSettings,
                 return internal_server_error(errormsg=res)
 
             if len(res['rows']) == 0:
-                return gone(gettext("The specified table could not be found."
-                                    ))
+                return gone(gettext(self.TABLE_NOT_FOUND_MSG))
 
             if status:
                 data = res['rows'][0]
@@ -1376,7 +1377,7 @@ class TableView(BaseTableView, DataTypeReader, VacuumSettings,
             return res
 
         if len(res['rows']) == 0:
-            return gone(gettext("The specified table could not be found."))
+            return gone(gettext(self.TABLE_NOT_FOUND_MSG))
 
         data = res['rows'][0]
 
@@ -1408,7 +1409,7 @@ class TableView(BaseTableView, DataTypeReader, VacuumSettings,
             return internal_server_error(errormsg=res)
 
         if len(res['rows']) == 0:
-            return gone(gettext("The specified table could not be found."))
+            return gone(gettext(self.TABLE_NOT_FOUND_MSG))
 
         data = res['rows'][0]
         data = self._formatter(did, scid, tid, data)
@@ -1456,7 +1457,7 @@ class TableView(BaseTableView, DataTypeReader, VacuumSettings,
             return internal_server_error(errormsg=res)
 
         if len(res['rows']) == 0:
-            return gone(gettext("The specified table could not be found."))
+            return gone(gettext(self.TABLE_NOT_FOUND_MSG))
 
         data = res['rows'][0]
         data = self._formatter(did, scid, tid, data)
@@ -1507,7 +1508,7 @@ class TableView(BaseTableView, DataTypeReader, VacuumSettings,
             return internal_server_error(errormsg=res)
 
         if len(res['rows']) == 0:
-            return gone(gettext("The specified table could not be found."))
+            return gone(gettext(self.TABLE_NOT_FOUND_MSG))
 
         data = res['rows'][0]
         data = self._formatter(did, scid, tid, data)
@@ -1560,7 +1561,7 @@ class TableView(BaseTableView, DataTypeReader, VacuumSettings,
             return internal_server_error(errormsg=res)
 
         if len(res['rows']) == 0:
-            return gone(gettext("The specified table could not be found."))
+            return gone(gettext(self.TABLE_NOT_FOUND_MSG))
 
         data = res['rows'][0]
 
@@ -1609,7 +1610,7 @@ class TableView(BaseTableView, DataTypeReader, VacuumSettings,
             super(TableView, self).get_schema_and_table_name(tid)
 
         if data['name'] is None:
-            return gone(gettext("The specified table could not be found."))
+            return gone(gettext(self.TABLE_NOT_FOUND_MSG))
 
         SQL = render_template(
             "/".join(
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/tables/columns/__init__.py b/web/pgadmin/browser/server_groups/servers/databases/schemas/tables/columns/__init__.py
index 5bf26b212..dbb067704 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/tables/columns/__init__.py
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/tables/columns/__init__.py
@@ -398,7 +398,7 @@ class ColumnsView(PGChildNodeView, DataTypeReader):
         data['schema'] = self.schema
         data['table'] = self.table
         if len(data['table']) == 0:
-            return gone(gettext("The specified table could not be found."))
+            return gone(gettext(self.TABLE_NOT_FOUND_MSG))
 
         # check type for '[]' in it
         data['cltype'], data['hasSqrBracket'] = \
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/tables/constraints/check_constraint/__init__.py b/web/pgadmin/browser/server_groups/servers/databases/schemas/tables/constraints/check_constraint/__init__.py
index 4e5501da2..30ae52d63 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/tables/constraints/check_constraint/__init__.py
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/tables/constraints/check_constraint/__init__.py
@@ -520,7 +520,7 @@ class CheckConstraintView(PGChildNodeView):
         data['table'] = self.table
         # Checking whether the table is deleted via query tool
         if len(data['table']) == 0:
-            return gone(_("The specified table could not be found."))
+            return gone(_(self.TABLE_NOT_FOUND_MSG))
 
         try:
             if 'name' not in data or data['name'] == "":
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/tables/constraints/foreign_key/__init__.py b/web/pgadmin/browser/server_groups/servers/databases/schemas/tables/constraints/foreign_key/__init__.py
index 48141f217..aa32fc561 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/tables/constraints/foreign_key/__init__.py
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/tables/constraints/foreign_key/__init__.py
@@ -111,7 +111,7 @@ class ForeignKeyConstraintModule(ConstraintTypeModule):
         """
         snippets = [
             render_template(
-                "browser/css/collection.css",
+                "/".join([self._BROWSER_CSS_PATH, self._COLLECTION_CSS]),
                 node_type=self.node_type,
             ),
             render_template(
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/tables/indexes/__init__.py b/web/pgadmin/browser/server_groups/servers/databases/schemas/tables/indexes/__init__.py
index e3f600de8..ea4776b3f 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/tables/indexes/__init__.py
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/tables/indexes/__init__.py
@@ -602,7 +602,7 @@ class IndexesView(PGChildNodeView, SchemaDiffObjectCompare):
         data['schema'] = self.schema
         data['table'] = self.table
         if len(data['table']) == 0:
-            return gone(gettext("The specified table could not be found."))
+            return gone(gettext(self.TABLE_NOT_FOUND_MSG))
 
         try:
             # Start transaction.
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/tables/partitions/__init__.py b/web/pgadmin/browser/server_groups/servers/databases/schemas/tables/partitions/__init__.py
index 0fbdbca1a..b69fd3f78 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/tables/partitions/__init__.py
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/tables/partitions/__init__.py
@@ -385,7 +385,7 @@ class PartitionsView(BaseTableView, DataTypeReader, VacuumSettings,
 
             if len(res['rows']) == 0:
                 return False, gone(
-                    gettext("The specified table could not be found."))
+                    gettext(self.TABLE_NOT_FOUND_MSG))
 
             # Update autovacuum properties
             self.update_autovacuum_properties(res['rows'][0])
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/tables/rules/__init__.py b/web/pgadmin/browser/server_groups/servers/databases/schemas/tables/rules/__init__.py
index 40151c3d9..2684aa276 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/tables/rules/__init__.py
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/tables/rules/__init__.py
@@ -106,7 +106,7 @@ class RuleModule(CollectionNodeModule):
         """
         snippets = [
             render_template(
-                "browser/css/collection.css",
+                "/".join([self._BROWSER_CSS_PATH, self._COLLECTION_CSS]),
                 node_type=self.node_type,
                 _=gettext
             ),
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/tables/utils.py b/web/pgadmin/browser/server_groups/servers/databases/schemas/tables/utils.py
index c23a9d91d..97f76e167 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/tables/utils.py
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/tables/utils.py
@@ -812,7 +812,7 @@ class BaseTableView(PGChildNodeView, BasePartitionTable):
         schema_name, table_name = self.get_schema_and_table_name(tid)
 
         if table_name is None:
-            return gone(gettext("The specified table could not be found."))
+            return gone(gettext(self.TABLE_NOT_FOUND_MSG))
 
         # table exist
         try:
@@ -1291,7 +1291,7 @@ class BaseTableView(PGChildNodeView, BasePartitionTable):
         schema_name, table_name = self.get_schema_and_table_name(tid)
 
         if table_name is None:
-            return gone(gettext("The specified table could not be found."))
+            return gone(gettext(self.TABLE_NOT_FOUND_MSG))
 
         # table exists
         try:
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/views/__init__.py b/web/pgadmin/browser/server_groups/servers/databases/schemas/views/__init__.py
index 557777fd5..6fa08adbd 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/views/__init__.py
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/views/__init__.py
@@ -109,7 +109,7 @@ class ViewModule(SchemaChildModule):
         """
         snippets = [
             render_template(
-                "browser/css/collection.css",
+                "/".join([self._BROWSER_CSS_PATH, self._COLLECTION_CSS]),
                 node_type=self.node_type,
                 _=gettext
             ),
diff --git a/web/pgadmin/browser/server_groups/servers/pgagent/__init__.py b/web/pgadmin/browser/server_groups/servers/pgagent/__init__.py
index b2c634cca..6f2432c78 100644
--- a/web/pgadmin/browser/server_groups/servers/pgagent/__init__.py
+++ b/web/pgadmin/browser/server_groups/servers/pgagent/__init__.py
@@ -90,7 +90,7 @@ SELECT EXISTS(
         """
         snippets = [
             render_template(
-                "browser/css/collection.css",
+                "/".join([self._BROWSER_CSS_PATH, self._COLLECTION_CSS]),
                 node_type=self.node_type,
                 _=_
             ),
diff --git a/web/pgadmin/browser/server_groups/servers/roles/__init__.py b/web/pgadmin/browser/server_groups/servers/roles/__init__.py
index b50ca3688..8aa1a23ef 100644
--- a/web/pgadmin/browser/server_groups/servers/roles/__init__.py
+++ b/web/pgadmin/browser/server_groups/servers/roles/__init__.py
@@ -63,7 +63,7 @@ class RoleModule(CollectionNodeModule):
         """
         snippets = [
             render_template(
-                "browser/css/collection.css",
+                "/".join([self._BROWSER_CSS_PATH, self._COLLECTION_CSS]),
                 node_type=self.node_type
             ),
             render_template("roles/css/role.css")]
diff --git a/web/pgadmin/browser/utils.py b/web/pgadmin/browser/utils.py
index e6e1c4664..5fa5f6f81 100644
--- a/web/pgadmin/browser/utils.py
+++ b/web/pgadmin/browser/utils.py
@@ -388,6 +388,9 @@ class PGChildNodeView(NodeView):
     _GET_DEFINITION_SQL = 'get_definition.sql'
     _GET_SCHEMA_OID_SQL = 'get_schema_oid.sql'
     _GET_COLUMNS_SQL = 'get_columns.sql'
+    _GET_COLUMNS_FOR_TABLE_SQL = 'get_columns_for_table.sql'
+
+    TABLE_NOT_FOUND_MSG = "The specified table could not be found."
 
     def get_children_nodes(self, manager, **kwargs):
         """
